@@ -134,8 +134,21 @@ sapply(studies, function(study) {
         name = "badcoeffs",
         timeStep = "weekly", 
         values = matrix(data = rep(0, 365 * 3), ncol = 3),
-        coefficients =  c("z%psp in" = 12, "b%null" = 0, "fr%de" = 0.5)
-      )
+        coefficients =  c("psp in%z" = 12, "b%null" = 0, "de%fr" = 0.5)
+      ), regexp = "not valid link"
+    )
+    
+  })
+  
+  test_that("Create a new binding constraint with coefficients not ordered alphabetically", {
+    
+    expect_error(
+      createBindingConstraint(
+        name = "not_ordered",
+        timeStep = "weekly", 
+        values = matrix(data = rep(0, 365 * 3), ncol = 3),
+        coefficients =  c("z%psp in" = 12, "fr%de" = 0)
+      ), regexp = "The areas are not sorted alphabetically"
     )
     
   })
